## mako
<%! import json %>
<%!
from django.utils.translation import ugettext as _
from openedx.core.djangolib.js_utils import (
    dump_js_escaped_json, js_escaped_string
)
%>
<%namespace name='static' file='/static_content.html'/>
<%inherit file="/main.html" />

<%block name="bodyclass">view-teams view-in-course course js</%block>
<%block name="pagetitle">${_("Acclaim")}</%block>

<%block name="headextra">
<%static:css group='style-course-vendor'/>
<%static:css group='style-course'/>
<%include file="../discussion/_js_head_dependencies.html" />
</%block>

<link rel="stylesheet" type="text/css" href="/static/acclaim_badges/css/acclaim.css">

<div class="container">
  <div class="acclaim-wrapper">

    <img class="acclaim-logo-add" src="/static/acclaim_badges/img/acclaim_logo.gif" height="39" width="160">
    <h3 class="acclaim-page-add">Authentication</h3>

    <form action="" method="post">
        <input type="hidden" name="csrfmiddlewaretoken" value="${ csrf_token }"/>
            ${ form.as_p() }
        <div class="submit-wrapper">
          <input id="submit-token" type="submit" value="Save" />
        </div>
    </form>

  </div>
</div>
