#id_badge_template{
  width: 200px;
  display: inline;
}

#id_auth_token{
  width: 300px;
}

#id_organization_id{
  width: 300px;
}

#id_url{
  width: 300px;
}

.acclaim td:last-child{
  white-space: nowrap;
}

.acclaim tr:first-child th{
    padding: 15px;
    border-top: 1px solid #D3D3D3;
    border-bottom: 1px solid #D3D3D3;
    font-weight: 600;
}

.acclaim tr:last-child th{
    border-bottom: 1px solid #D3D3D3;
}

.acclaim-form-title {
  padding-top: 30px;
  padding-bottom: 15px;
}

.container > div{
    background-color: #f5f5f5;
    box-shadow: 0 0 0 0;
    border: 0px;
}

.submit-wrapper {
  padding-top: 35px;
}

.acclaim-wrapper {
    max-width: 1180px;
    margin: 0 auto;
    padding: 0;
    background-color: #bbff00;
}

.acclaim-page-title{
    padding-bottom: 30px;
    padding-right: 30px;
    font-weight: 600;
    float: left;
}

.acclaim-page-add{
    padding-bottom: 15px;
    padding-top: 30px;
    font-weight: 600;
}

.acclaim-logo-delete{
  padding-bottom: 30px;
  padding-top: 30px;
}

.acclaim-logo{
  display: block;
  float: left;
}

.acclaim-logo-add{
  padding-top: 30px;
  display: block;
}

.acclaim-buttons{
    padding-top: 30px;
    padding-bottom: 30px;
    display: block;
    font-weight: bold;
}

table, th, td {
    padding: 15px;
    text-align: left;
    font-weight: normal;
}

table a {
    padding: 15px;
    font-weight: bold;
}

.acclaim {
  display: block;
  float: left;
}

.form-message{
  display: inline;
  padding-right: 20px;
}

#btn-test {
  padding:5px 15px; 
  background: #0075b4; 
  border:0 none;
  cursor:pointer;
  border-radius: 5px; 
  width: 100px;
  color: white;
  font-weight: 500;
}

#submit-token {
  background: #0075b4; 
  border:0 none;
  cursor:pointer;
  border-radius: 5px; 
  width: 300px;
  color: white;
}


.acclaim-button {
  border-radius: 2px;
  background-color: #0075b4;
  border: none;
  color: white;
  padding: 15px 32px;
  text-align: center;
  display: inline-block;
  font-size: 16px;
	width: 150px;
  float: right;
}

.acclaim-button-text {
  color: white;
}

.wrapper-inner{
  padding-right: 15px;
}

.wrapper-test {
  padding-top: 60px;
  padding-right: 15px;
  float: left;
  clear: both;
}

div.acclaim-button a:visited {
	color: white;
}

div.acclaim-button a:hover {
	color: #005584;
}
