"""
Acclaim Badges for EDX.
"""

from __future__ import absolute_import, unicode_literals

__version__ = '0.1.0'

default_app_config = 'acclaim_badges.apps.AcclaimBadgesConfig'  # pylint: disable=invalid-name
